#' @importFrom flextable save_as_docx
#' @export
flextable::save_as_docx

#' @importFrom flextable save_as_html
#' @export
flextable::save_as_html

#' @importFrom flextable save_as_image
#' @export
flextable::save_as_image

#' @importFrom flextable save_as_pptx
#' @export
flextable::save_as_pptx
